use eframe::egui::{self, Response, Ui, Widget};

use super::{model_response::ModelResponse, state::AppState};

pub struct ModelSelection<'a> {
    app_state: &'a mut AppState,
}

impl<'a> ModelSelection<'a> {
    pub fn new(app_state: &'a mut AppState) -> Self {
        Self { app_state }
    }
}

impl<'a> Widget for ModelSelection<'a> {
    fn ui(self, ui: &mut Ui) -> Response {
        ui.horizontal(|ui| {
            egui::ComboBox::from_label("")
                .selected_text("Models")
                .show_ui(ui, |ui| {
                    for model in &self.app_state.models_available {
                        let selected_models = self
                            .app_state
                            .selected_models
                            .iter()
                            .map(|m| m.name.clone())
                            .collect::<Vec<String>>();
                        let contained = selected_models.contains(&model);

                        let label = ui.selectable_label(contained, model);

                        if label.clicked() && !contained {
                            self.app_state.selected_models.push(ModelResponse {
                                name: model.clone(),
                                message: "No message".to_string(),
                                status: 0,
                                time: 0.0,
                            });
                        }
                    }
                });

            let mut model_to_remove: Option<String> = None;

            for model in &self.app_state.selected_models {
                egui::Frame::none()
                    .inner_margin(8.0)
                    .rounding(4.0)
                    .fill(egui::Color32::WHITE)
                    .show(ui, |ui| {
                        ui.horizontal(|ui| {
                            ui.label(model.name.clone());
                            if ui.button("X").clicked() {
                                model_to_remove.replace(model.name.clone());
                            }
                        });
                    });
            }

            if let Some(model) = model_to_remove {
                self.app_state.selected_models.retain(|m| m.name != model);
            }
        })
        .response
    }
}
