use eframe::{egui, CreationContext};

use super::{model_response::ModelResponse, model_selection, prompt_input};

pub struct AppState {
    pub selected_models: Vec<ModelResponse>,
    pub prompt_input: String,
    pub models_available: Vec<String>,
}

impl AppState {
    pub fn new(_cc: &CreationContext<'_>, models_available: Vec<String>) -> Self {
        Self {
            selected_models: vec![],
            prompt_input: String::new(),
            models_available,
        }
    }

    pub async fn handle_submission(&mut self) {
        let mut completions = vec![];

        for model in &mut self.selected_models {
            completions.push(model.chat_completion(self.prompt_input.clone()));
        }

        futures::future::join_all(completions).await;
    }
}

impl eframe::App for AppState {
    fn update(&mut self, ctx: &egui::Context, _frame: &mut eframe::Frame) {
        egui::CentralPanel::default().show(ctx, |ui| {
            ui.heading("Groq Model Comparison");
            ui.label("Compare Groq models with ease!");

            ui.add(model_selection::ModelSelection::new(self));

            ui.add(prompt_input::PromptInput::new(self));

            ui.horizontal(|ui| {
                for model in &self.selected_models {
                    ui.vertical(|ui| ui.add(model));
                }
            });
        });
    }
}
